@@ -1,36 +1,43 @@
-/*global Dashboard*/
+/* global $, Dashboard */
+
 var dashboard = new Dashboard();
 
 dashboard.addWidget('clock_widget', 'Clock');
 
 dashboard.addWidget('current_valuation_widget', 'Number', {
     getData: function () {
-        this.data = {
+        $.extend(this.data, {
             title: 'Current Valuation',
             more_info: 'In billions',
             updated_at: 'Last updated at 14:10',
-            change_rate: '64%',
+            detail: '64%',
             value: '$35'
-        };
-        dashboard.publish('current_valuation_widget/render');
+        });
     }
 });
 
 dashboard.addWidget('buzzwords_widget', 'List', {
     getData: function () {
-        this.data = {
+        $.extend(this.data, {
             title: 'Buzzwords',
             more_info: '# of times said around the office',
             updated_at: 'Last updated at 18:58',
-            data: [{'Exit strategy': 24}, {'Web 2.0': 12}, {'Turn-key': 2}, {'Enterprise': 12}, {'Pivoting': 3}, {'Leverage': 10}, {'Streamlininess': 4}, {'Paradigm shift': 6}, {'Synergy': 7}]
-        };
-        dashboard.publish('buzzwords_widget/render');
+            data: [{label: 'Exit strategy', value: 24},
+                   {label: 'Web 2.0', value: 12},
+                   {label: 'Turn-key', value: 2},
+                   {label: 'Enterprise', value: 12},
+                   {label: 'Pivoting', value: 3},
+                   {label: 'Leverage', value: 10},
+                   {label: 'Streamlininess', value: 4},
+                   {label: 'Paradigm shift', value: 6},
+                   {label: 'Synergy', value: 7}]
+        });
     }
 });
 
 dashboard.addWidget('convergence_widget', 'Graph', {
     getData: function () {
-        this.data = {
+        $.extend(this.data, {
             title: 'Convergence',
             value: '41',
             more_info: '',
@@ -41,7 +48,6 @@ dashboard.addWidget('convergence_widget', 'Graph', {
                     { x: 3, y: 30 }, 
                     { x: 4, y: 32 }
                 ]
-            };
-        dashboard.publish('convergence_widget/render');
+            });
     }
 });
